Class: Aws::BedrockDataAutomation::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BedrockDataAutomation::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bedrockdataautomation/client.rb,
sig/client.rbs
Overview
An API client for BedrockDataAutomation. To construct a client, you need to configure a :region and :credentials.
client = Aws::BedrockDataAutomation::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CopyBlueprintStageResponseSuccess, _CreateBlueprintResponseSuccess, _CreateBlueprintVersionResponseSuccess, _CreateDataAutomationLibraryResponseSuccess, _CreateDataAutomationProjectResponseSuccess, _DeleteBlueprintResponseSuccess, _DeleteDataAutomationLibraryResponseSuccess, _DeleteDataAutomationProjectResponseSuccess, _GetBlueprintOptimizationStatusResponseSuccess, _GetBlueprintResponseSuccess, _GetDataAutomationLibraryEntityResponseSuccess, _GetDataAutomationLibraryIngestionJobResponseSuccess, _GetDataAutomationLibraryResponseSuccess, _GetDataAutomationProjectResponseSuccess, _InvokeBlueprintOptimizationAsyncResponseSuccess, _InvokeDataAutomationLibraryIngestionJobResponseSuccess, _ListBlueprintsResponseSuccess, _ListDataAutomationLibrariesResponseSuccess, _ListDataAutomationLibraryEntitiesResponseSuccess, _ListDataAutomationLibraryIngestionJobsResponseSuccess, _ListDataAutomationProjectsResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateBlueprintResponseSuccess, _UpdateDataAutomationLibraryResponseSuccess, _UpdateDataAutomationProjectResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#copy_blueprint_stage(params = {}) ⇒ Struct
Copies a Blueprint from one stage to another.
-
#create_blueprint(params = {}) ⇒ Types::CreateBlueprintResponse
Creates an Amazon Bedrock Data Automation Blueprint.
-
#create_blueprint_version(params = {}) ⇒ Types::CreateBlueprintVersionResponse
Creates a new version of an existing Amazon Bedrock Data Automation Blueprint.
-
#create_data_automation_library(params = {}) ⇒ Types::CreateDataAutomationLibraryResponse
Creates an Amazon Bedrock Data Automation Library.
-
#create_data_automation_project(params = {}) ⇒ Types::CreateDataAutomationProjectResponse
Creates an Amazon Bedrock Data Automation Project.
-
#delete_blueprint(params = {}) ⇒ Struct
Deletes an existing Amazon Bedrock Data Automation Blueprint.
-
#delete_data_automation_library(params = {}) ⇒ Types::DeleteDataAutomationLibraryResponse
Deletes an existing Amazon Bedrock Data Automation Library.
-
#delete_data_automation_project(params = {}) ⇒ Types::DeleteDataAutomationProjectResponse
Deletes an existing Amazon Bedrock Data Automation Project.
-
#get_blueprint(params = {}) ⇒ Types::GetBlueprintResponse
Gets an existing Amazon Bedrock Data Automation Blueprint.
-
#get_blueprint_optimization_status(params = {}) ⇒ Types::GetBlueprintOptimizationStatusResponse
API used to get blueprint optimization status.
-
#get_data_automation_library(params = {}) ⇒ Types::GetDataAutomationLibraryResponse
Gets an existing Amazon Bedrock Data Automation Library.
-
#get_data_automation_library_entity(params = {}) ⇒ Types::GetDataAutomationLibraryEntityResponse
Gets an existing entity based on entity type from the library.
-
#get_data_automation_library_ingestion_job(params = {}) ⇒ Types::GetDataAutomationLibraryIngestionJobResponse
API used to get status of data automation library ingestion job.
-
#get_data_automation_project(params = {}) ⇒ Types::GetDataAutomationProjectResponse
Gets an existing Amazon Bedrock Data Automation Project.
-
#invoke_blueprint_optimization_async(params = {}) ⇒ Types::InvokeBlueprintOptimizationAsyncResponse
Invoke an async job to perform Blueprint Optimization.
-
#invoke_data_automation_library_ingestion_job(params = {}) ⇒ Types::InvokeDataAutomationLibraryIngestionJobResponse
Async API: Invoke data automation library ingestion job.
-
#list_blueprints(params = {}) ⇒ Types::ListBlueprintsResponse
Lists all existing Amazon Bedrock Data Automation Blueprints.
-
#list_data_automation_libraries(params = {}) ⇒ Types::ListDataAutomationLibrariesResponse
Lists all existing Amazon Bedrock Data Automation Libraries.
-
#list_data_automation_library_entities(params = {}) ⇒ Types::ListDataAutomationLibraryEntitiesResponse
Lists all stored entities in the library.
-
#list_data_automation_library_ingestion_jobs(params = {}) ⇒ Types::ListDataAutomationLibraryIngestionJobsResponse
Lists all data automation library ingestion jobs.
-
#list_data_automation_projects(params = {}) ⇒ Types::ListDataAutomationProjectsResponse
Lists all existing Amazon Bedrock Data Automation Projects.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource.
-
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource.
-
#update_blueprint(params = {}) ⇒ Types::UpdateBlueprintResponse
Updates an existing Amazon Bedrock Data Automation Blueprint.
-
#update_data_automation_library(params = {}) ⇒ Types::UpdateDataAutomationLibraryResponse
Updates an existing Amazon Bedrock Data Automation Library.
-
#update_data_automation_project(params = {}) ⇒ Types::UpdateDataAutomationProjectResponse
Updates an existing Amazon Bedrock Data Automation Project.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2264 2265 2266 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2264 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2267 2268 2269 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2267 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2237 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BedrockDataAutomation') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bedrockdataautomation' context[:gem_version] = '1.34.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_blueprint_stage(params = {}) ⇒ Struct
Copies a Blueprint from one stage to another
85 |
# File 'sig/client.rbs', line 85
def copy_blueprint_stage: (
|
#create_blueprint(params = {}) ⇒ Types::CreateBlueprintResponse
Creates an Amazon Bedrock Data Automation Blueprint
98 |
# File 'sig/client.rbs', line 98
def create_blueprint: (
|
#create_blueprint_version(params = {}) ⇒ Types::CreateBlueprintVersionResponse
Creates a new version of an existing Amazon Bedrock Data Automation Blueprint
122 |
# File 'sig/client.rbs', line 122
def create_blueprint_version: (
|
#create_data_automation_library(params = {}) ⇒ Types::CreateDataAutomationLibraryResponse
Creates an Amazon Bedrock Data Automation Library
134 |
# File 'sig/client.rbs', line 134
def create_data_automation_library: (
|
#create_data_automation_project(params = {}) ⇒ Types::CreateDataAutomationProjectResponse
Creates an Amazon Bedrock Data Automation Project
158 |
# File 'sig/client.rbs', line 158
def create_data_automation_project: (
|
#delete_blueprint(params = {}) ⇒ Struct
Deletes an existing Amazon Bedrock Data Automation Blueprint
191 |
# File 'sig/client.rbs', line 191
def delete_blueprint: (
|
#delete_data_automation_library(params = {}) ⇒ Types::DeleteDataAutomationLibraryResponse
Deletes an existing Amazon Bedrock Data Automation Library
203 |
# File 'sig/client.rbs', line 203
def delete_data_automation_library: (
|
#delete_data_automation_project(params = {}) ⇒ Types::DeleteDataAutomationProjectResponse
Deletes an existing Amazon Bedrock Data Automation Project
214 |
# File 'sig/client.rbs', line 214
def delete_data_automation_project: (
|
#get_blueprint(params = {}) ⇒ Types::GetBlueprintResponse
Gets an existing Amazon Bedrock Data Automation Blueprint
224 |
# File 'sig/client.rbs', line 224
def get_blueprint: (
|
#get_blueprint_optimization_status(params = {}) ⇒ Types::GetBlueprintOptimizationStatusResponse
API used to get blueprint optimization status.
239 |
# File 'sig/client.rbs', line 239
def get_blueprint_optimization_status: (
|
#get_data_automation_library(params = {}) ⇒ Types::GetDataAutomationLibraryResponse
Gets an existing Amazon Bedrock Data Automation Library
249 |
# File 'sig/client.rbs', line 249
def get_data_automation_library: (
|
#get_data_automation_library_entity(params = {}) ⇒ Types::GetDataAutomationLibraryEntityResponse
Gets an existing entity based on entity type from the library
259 |
# File 'sig/client.rbs', line 259
def get_data_automation_library_entity: (
|
#get_data_automation_library_ingestion_job(params = {}) ⇒ Types::GetDataAutomationLibraryIngestionJobResponse
API used to get status of data automation library ingestion job
271 |
# File 'sig/client.rbs', line 271
def get_data_automation_library_ingestion_job: (
|
#get_data_automation_project(params = {}) ⇒ Types::GetDataAutomationProjectResponse
Gets an existing Amazon Bedrock Data Automation Project
282 |
# File 'sig/client.rbs', line 282
def get_data_automation_project: (
|
#invoke_blueprint_optimization_async(params = {}) ⇒ Types::InvokeBlueprintOptimizationAsyncResponse
Invoke an async job to perform Blueprint Optimization
293 |
# File 'sig/client.rbs', line 293
def invoke_blueprint_optimization_async: (
|
#invoke_data_automation_library_ingestion_job(params = {}) ⇒ Types::InvokeDataAutomationLibraryIngestionJobResponse
Async API: Invoke data automation library ingestion job
335 |
# File 'sig/client.rbs', line 335
def invoke_data_automation_library_ingestion_job: (
|
#list_blueprints(params = {}) ⇒ Types::ListBlueprintsResponse
Lists all existing Amazon Bedrock Data Automation Blueprints
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
389 |
# File 'sig/client.rbs', line 389
def list_blueprints: (
|
#list_data_automation_libraries(params = {}) ⇒ Types::ListDataAutomationLibrariesResponse
Lists all existing Amazon Bedrock Data Automation Libraries
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
408 |
# File 'sig/client.rbs', line 408
def list_data_automation_libraries: (
|
#list_data_automation_library_entities(params = {}) ⇒ Types::ListDataAutomationLibraryEntitiesResponse
Lists all stored entities in the library
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
424 |
# File 'sig/client.rbs', line 424
def list_data_automation_library_entities: (
|
#list_data_automation_library_ingestion_jobs(params = {}) ⇒ Types::ListDataAutomationLibraryIngestionJobsResponse
Lists all data automation library ingestion jobs
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
438 |
# File 'sig/client.rbs', line 438
def list_data_automation_library_ingestion_jobs: (
|
#list_data_automation_projects(params = {}) ⇒ Types::ListDataAutomationProjectsResponse
Lists all existing Amazon Bedrock Data Automation Projects
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
451 |
# File 'sig/client.rbs', line 451
def list_data_automation_projects: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource
472 |
# File 'sig/client.rbs', line 472
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource
481 |
# File 'sig/client.rbs', line 481
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource
496 |
# File 'sig/client.rbs', line 496
def untag_resource: (
|
#update_blueprint(params = {}) ⇒ Types::UpdateBlueprintResponse
Updates an existing Amazon Bedrock Data Automation Blueprint
507 |
# File 'sig/client.rbs', line 507
def update_blueprint: (
|
#update_data_automation_library(params = {}) ⇒ Types::UpdateDataAutomationLibraryResponse
Updates an existing Amazon Bedrock Data Automation Library
524 |
# File 'sig/client.rbs', line 524
def update_data_automation_library: (
|
#update_data_automation_project(params = {}) ⇒ Types::UpdateDataAutomationProjectResponse
Updates an existing Amazon Bedrock Data Automation Project
538 |
# File 'sig/client.rbs', line 538
def update_data_automation_project: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2257 2258 2259 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2257 def waiter_names [] end |