Class: Aws::BedrockDataAutomation::Types::DeleteDataAutomationLibraryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockDataAutomation::Types::DeleteDataAutomationLibraryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockdataautomation/types.rb
Overview
Delete DataAutomationLibrary Request
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#library_arn ⇒ String
ARN generated at the server side when a DataAutomationLibrary is created.
Instance Attribute Details
#library_arn ⇒ String
ARN generated at the server side when a DataAutomationLibrary is created
1104 1105 1106 1107 1108 |
# File 'lib/aws-sdk-bedrockdataautomation/types.rb', line 1104 class DeleteDataAutomationLibraryRequest < Struct.new( :library_arn) SENSITIVE = [] include Aws::Structure end |