Class: Aws::BedrockDataAutomation::Types::EntityTypeInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockDataAutomation::Types::EntityTypeInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockdataautomation/types.rb
Overview
Information about an entity type in the DataAutomationLibrary
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entity_metadata ⇒ String
JSON string representing relevant metadata for the entity type.
-
#entity_type ⇒ String
Entity types supported in DataAutomationLibraries.
Instance Attribute Details
#entity_metadata ⇒ String
JSON string representing relevant metadata for the entity type
1400 1401 1402 1403 1404 1405 |
# File 'lib/aws-sdk-bedrockdataautomation/types.rb', line 1400 class EntityTypeInfo < Struct.new( :entity_type, :entity_metadata) SENSITIVE = [] include Aws::Structure end |
#entity_type ⇒ String
Entity types supported in DataAutomationLibraries
1400 1401 1402 1403 1404 1405 |
# File 'lib/aws-sdk-bedrockdataautomation/types.rb', line 1400 class EntityTypeInfo < Struct.new( :entity_type, :entity_metadata) SENSITIVE = [] include Aws::Structure end |