Class: Aws::BedrockDataAutomation::Types::InvokeDataAutomationLibraryIngestionJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockDataAutomation::Types::InvokeDataAutomationLibraryIngestionJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockdataautomation/types.rb
Overview
Invoke DataAutomationLibraryIngestionJob Request
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Idempotency token.
-
#entity_type ⇒ String
The entity type for which DataAutomationLibraryIngestionJob is being run.
-
#input_configuration ⇒ Types::InputConfiguration
Input configuration of DataAutomationLibraryIngestionJob request.
-
#library_arn ⇒ String
ARN generated at the server side when a DataAutomationLibrary is created.
-
#notification_configuration ⇒ Types::NotificationConfiguration
Notification configuration.
-
#operation_type ⇒ String
The operation to be performed by DataAutomationLibraryIngestionJob.
-
#output_configuration ⇒ Types::OutputConfiguration
Output configuration of DataAutomationLibraryIngestionJob.
-
#tags ⇒ Array<Types::Tag>
List of tags.
Instance Attribute Details
#client_token ⇒ String
Idempotency token
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-bedrockdataautomation/types.rb', line 1903 class InvokeDataAutomationLibraryIngestionJobRequest < Struct.new( :library_arn, :client_token, :input_configuration, :entity_type, :operation_type, :output_configuration, :notification_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#entity_type ⇒ String
The entity type for which DataAutomationLibraryIngestionJob is being run
1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-bedrockdataautomation/types.rb', line 1903 class InvokeDataAutomationLibraryIngestionJobRequest < Struct.new( :library_arn, :client_token, :input_configuration, :entity_type, :operation_type, :output_configuration, :notification_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#input_configuration ⇒ Types::InputConfiguration
Input configuration of DataAutomationLibraryIngestionJob request
1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-bedrockdataautomation/types.rb', line 1903 class InvokeDataAutomationLibraryIngestionJobRequest < Struct.new( :library_arn, :client_token, :input_configuration, :entity_type, :operation_type, :output_configuration, :notification_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#library_arn ⇒ String
ARN generated at the server side when a DataAutomationLibrary is created
1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-bedrockdataautomation/types.rb', line 1903 class InvokeDataAutomationLibraryIngestionJobRequest < Struct.new( :library_arn, :client_token, :input_configuration, :entity_type, :operation_type, :output_configuration, :notification_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#notification_configuration ⇒ Types::NotificationConfiguration
Notification configuration.
1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-bedrockdataautomation/types.rb', line 1903 class InvokeDataAutomationLibraryIngestionJobRequest < Struct.new( :library_arn, :client_token, :input_configuration, :entity_type, :operation_type, :output_configuration, :notification_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#operation_type ⇒ String
The operation to be performed by DataAutomationLibraryIngestionJob
1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-bedrockdataautomation/types.rb', line 1903 class InvokeDataAutomationLibraryIngestionJobRequest < Struct.new( :library_arn, :client_token, :input_configuration, :entity_type, :operation_type, :output_configuration, :notification_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#output_configuration ⇒ Types::OutputConfiguration
Output configuration of DataAutomationLibraryIngestionJob
1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-bedrockdataautomation/types.rb', line 1903 class InvokeDataAutomationLibraryIngestionJobRequest < Struct.new( :library_arn, :client_token, :input_configuration, :entity_type, :operation_type, :output_configuration, :notification_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
List of tags
1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-bedrockdataautomation/types.rb', line 1903 class InvokeDataAutomationLibraryIngestionJobRequest < Struct.new( :library_arn, :client_token, :input_configuration, :entity_type, :operation_type, :output_configuration, :notification_configuration, :tags) SENSITIVE = [] include Aws::Structure end |