Class: Aws::BedrockDataAutomation::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BedrockDataAutomation::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bedrockdataautomation/client.rb
Overview
An API client for BedrockDataAutomation. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::BedrockDataAutomation::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#copy_blueprint_stage(params = {}) ⇒ Struct
Copies a Blueprint from one stage to another.
-
#create_blueprint(params = {}) ⇒ Types::CreateBlueprintResponse
Creates an Amazon Bedrock Data Automation Blueprint.
-
#create_blueprint_version(params = {}) ⇒ Types::CreateBlueprintVersionResponse
Creates a new version of an existing Amazon Bedrock Data Automation Blueprint.
-
#create_data_automation_library(params = {}) ⇒ Types::CreateDataAutomationLibraryResponse
Creates an Amazon Bedrock Data Automation Library.
-
#create_data_automation_project(params = {}) ⇒ Types::CreateDataAutomationProjectResponse
Creates an Amazon Bedrock Data Automation Project.
-
#delete_blueprint(params = {}) ⇒ Struct
Deletes an existing Amazon Bedrock Data Automation Blueprint.
-
#delete_data_automation_library(params = {}) ⇒ Types::DeleteDataAutomationLibraryResponse
Deletes an existing Amazon Bedrock Data Automation Library.
-
#delete_data_automation_project(params = {}) ⇒ Types::DeleteDataAutomationProjectResponse
Deletes an existing Amazon Bedrock Data Automation Project.
-
#get_blueprint(params = {}) ⇒ Types::GetBlueprintResponse
Gets an existing Amazon Bedrock Data Automation Blueprint.
-
#get_blueprint_optimization_status(params = {}) ⇒ Types::GetBlueprintOptimizationStatusResponse
API used to get blueprint optimization status.
-
#get_data_automation_library(params = {}) ⇒ Types::GetDataAutomationLibraryResponse
Gets an existing Amazon Bedrock Data Automation Library.
-
#get_data_automation_library_entity(params = {}) ⇒ Types::GetDataAutomationLibraryEntityResponse
Gets an existing entity based on entity type from the library.
-
#get_data_automation_library_ingestion_job(params = {}) ⇒ Types::GetDataAutomationLibraryIngestionJobResponse
API used to get status of data automation library ingestion job.
-
#get_data_automation_project(params = {}) ⇒ Types::GetDataAutomationProjectResponse
Gets an existing Amazon Bedrock Data Automation Project.
-
#invoke_blueprint_optimization_async(params = {}) ⇒ Types::InvokeBlueprintOptimizationAsyncResponse
Invoke an async job to perform Blueprint Optimization.
-
#invoke_data_automation_library_ingestion_job(params = {}) ⇒ Types::InvokeDataAutomationLibraryIngestionJobResponse
Async API: Invoke data automation library ingestion job.
-
#list_blueprints(params = {}) ⇒ Types::ListBlueprintsResponse
Lists all existing Amazon Bedrock Data Automation Blueprints.
-
#list_data_automation_libraries(params = {}) ⇒ Types::ListDataAutomationLibrariesResponse
Lists all existing Amazon Bedrock Data Automation Libraries.
-
#list_data_automation_library_entities(params = {}) ⇒ Types::ListDataAutomationLibraryEntitiesResponse
Lists all stored entities in the library.
-
#list_data_automation_library_ingestion_jobs(params = {}) ⇒ Types::ListDataAutomationLibraryIngestionJobsResponse
Lists all data automation library ingestion jobs.
-
#list_data_automation_projects(params = {}) ⇒ Types::ListDataAutomationProjectsResponse
Lists all existing Amazon Bedrock Data Automation Projects.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource.
-
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource.
-
#update_blueprint(params = {}) ⇒ Types::UpdateBlueprintResponse
Updates an existing Amazon Bedrock Data Automation Blueprint.
-
#update_data_automation_library(params = {}) ⇒ Types::UpdateDataAutomationLibraryResponse
Updates an existing Amazon Bedrock Data Automation Library.
-
#update_data_automation_project(params = {}) ⇒ Types::UpdateDataAutomationProjectResponse
Updates an existing Amazon Bedrock Data Automation Project.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2264 2265 2266 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2264 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2267 2268 2269 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2267 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2237 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BedrockDataAutomation') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bedrockdataautomation' context[:gem_version] = '1.33.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_blueprint_stage(params = {}) ⇒ Struct
Copies a Blueprint from one stage to another
509 510 511 512 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 509 def copy_blueprint_stage(params = {}, = {}) req = build_request(:copy_blueprint_stage, params) req.send_request() end |
#create_blueprint(params = {}) ⇒ Types::CreateBlueprintResponse
Creates an Amazon Bedrock Data Automation Blueprint
590 591 592 593 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 590 def create_blueprint(params = {}, = {}) req = build_request(:create_blueprint, params) req.send_request() end |
#create_blueprint_version(params = {}) ⇒ Types::CreateBlueprintVersionResponse
Creates a new version of an existing Amazon Bedrock Data Automation Blueprint
642 643 644 645 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 642 def create_blueprint_version(params = {}, = {}) req = build_request(:create_blueprint_version, params) req.send_request() end |
#create_data_automation_library(params = {}) ⇒ Types::CreateDataAutomationLibraryResponse
Creates an Amazon Bedrock Data Automation Library
701 702 703 704 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 701 def create_data_automation_library(params = {}, = {}) req = build_request(:create_data_automation_library, params) req.send_request() end |
#create_data_automation_project(params = {}) ⇒ Types::CreateDataAutomationProjectResponse
Creates an Amazon Bedrock Data Automation Project
950 951 952 953 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 950 def create_data_automation_project(params = {}, = {}) req = build_request(:create_data_automation_project, params) req.send_request() end |
#delete_blueprint(params = {}) ⇒ Struct
Deletes an existing Amazon Bedrock Data Automation Blueprint
976 977 978 979 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 976 def delete_blueprint(params = {}, = {}) req = build_request(:delete_blueprint, params) req.send_request() end |
#delete_data_automation_library(params = {}) ⇒ Types::DeleteDataAutomationLibraryResponse
Deletes an existing Amazon Bedrock Data Automation Library
1007 1008 1009 1010 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1007 def delete_data_automation_library(params = {}, = {}) req = build_request(:delete_data_automation_library, params) req.send_request() end |
#delete_data_automation_project(params = {}) ⇒ Types::DeleteDataAutomationProjectResponse
Deletes an existing Amazon Bedrock Data Automation Project
1038 1039 1040 1041 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1038 def delete_data_automation_project(params = {}, = {}) req = build_request(:delete_data_automation_project, params) req.send_request() end |
#get_blueprint(params = {}) ⇒ Types::GetBlueprintResponse
Gets an existing Amazon Bedrock Data Automation Blueprint
1090 1091 1092 1093 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1090 def get_blueprint(params = {}, = {}) req = build_request(:get_blueprint, params) req.send_request() end |
#get_blueprint_optimization_status(params = {}) ⇒ Types::GetBlueprintOptimizationStatusResponse
API used to get blueprint optimization status.
1125 1126 1127 1128 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1125 def get_blueprint_optimization_status(params = {}, = {}) req = build_request(:get_blueprint_optimization_status, params) req.send_request() end |
#get_data_automation_library(params = {}) ⇒ Types::GetDataAutomationLibraryResponse
Gets an existing Amazon Bedrock Data Automation Library
1164 1165 1166 1167 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1164 def get_data_automation_library(params = {}, = {}) req = build_request(:get_data_automation_library, params) req.send_request() end |
#get_data_automation_library_entity(params = {}) ⇒ Types::GetDataAutomationLibraryEntityResponse
Gets an existing entity based on entity type from the library
1207 1208 1209 1210 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1207 def get_data_automation_library_entity(params = {}, = {}) req = build_request(:get_data_automation_library_entity, params) req.send_request() end |
#get_data_automation_library_ingestion_job(params = {}) ⇒ Types::GetDataAutomationLibraryIngestionJobResponse
API used to get status of data automation library ingestion job
1248 1249 1250 1251 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1248 def get_data_automation_library_ingestion_job(params = {}, = {}) req = build_request(:get_data_automation_library_ingestion_job, params) req.send_request() end |
#get_data_automation_project(params = {}) ⇒ Types::GetDataAutomationProjectResponse
Gets an existing Amazon Bedrock Data Automation Project
1367 1368 1369 1370 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1367 def get_data_automation_project(params = {}, = {}) req = build_request(:get_data_automation_project, params) req.send_request() end |
#invoke_blueprint_optimization_async(params = {}) ⇒ Types::InvokeBlueprintOptimizationAsyncResponse
Invoke an async job to perform Blueprint Optimization
1444 1445 1446 1447 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1444 def invoke_blueprint_optimization_async(params = {}, = {}) req = build_request(:invoke_blueprint_optimization_async, params) req.send_request() end |
#invoke_data_automation_library_ingestion_job(params = {}) ⇒ Types::InvokeDataAutomationLibraryIngestionJobResponse
Async API: Invoke data automation library ingestion job
1541 1542 1543 1544 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1541 def invoke_data_automation_library_ingestion_job(params = {}, = {}) req = build_request(:invoke_data_automation_library_ingestion_job, params) req.send_request() end |
#list_blueprints(params = {}) ⇒ Types::ListBlueprintsResponse
Lists all existing Amazon Bedrock Data Automation Blueprints
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1602 1603 1604 1605 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1602 def list_blueprints(params = {}, = {}) req = build_request(:list_blueprints, params) req.send_request() end |
#list_data_automation_libraries(params = {}) ⇒ Types::ListDataAutomationLibrariesResponse
Lists all existing Amazon Bedrock Data Automation Libraries
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1648 1649 1650 1651 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1648 def list_data_automation_libraries(params = {}, = {}) req = build_request(:list_data_automation_libraries, params) req.send_request() end |
#list_data_automation_library_entities(params = {}) ⇒ Types::ListDataAutomationLibraryEntitiesResponse
Lists all stored entities in the library
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1698 1699 1700 1701 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1698 def list_data_automation_library_entities(params = {}, = {}) req = build_request(:list_data_automation_library_entities, params) req.send_request() end |
#list_data_automation_library_ingestion_jobs(params = {}) ⇒ Types::ListDataAutomationLibraryIngestionJobsResponse
Lists all data automation library ingestion jobs
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1745 1746 1747 1748 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1745 def list_data_automation_library_ingestion_jobs(params = {}, = {}) req = build_request(:list_data_automation_library_ingestion_jobs, params) req.send_request() end |
#list_data_automation_projects(params = {}) ⇒ Types::ListDataAutomationProjectsResponse
Lists all existing Amazon Bedrock Data Automation Projects
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1808 1809 1810 1811 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1808 def list_data_automation_projects(params = {}, = {}) req = build_request(:list_data_automation_projects, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource
1838 1839 1840 1841 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1838 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource
1869 1870 1871 1872 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1869 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource
1895 1896 1897 1898 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1895 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_blueprint(params = {}) ⇒ Types::UpdateBlueprintResponse
Updates an existing Amazon Bedrock Data Automation Blueprint
1956 1957 1958 1959 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1956 def update_blueprint(params = {}, = {}) req = build_request(:update_blueprint, params) req.send_request() end |
#update_data_automation_library(params = {}) ⇒ Types::UpdateDataAutomationLibraryResponse
Updates an existing Amazon Bedrock Data Automation Library
1998 1999 2000 2001 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1998 def update_data_automation_library(params = {}, = {}) req = build_request(:update_data_automation_library, params) req.send_request() end |
#update_data_automation_project(params = {}) ⇒ Types::UpdateDataAutomationProjectResponse
Updates an existing Amazon Bedrock Data Automation Project
2228 2229 2230 2231 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2228 def update_data_automation_project(params = {}, = {}) req = build_request(:update_data_automation_project, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2257 2258 2259 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2257 def waiter_names [] end |