Class: Aws::BedrockDataAutomation::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BedrockDataAutomation::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bedrockdataautomation/client.rb
Overview
An API client for BedrockDataAutomation. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::BedrockDataAutomation::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#copy_blueprint_stage(params = {}) ⇒ Struct
Copies a Blueprint from one stage to another.
-
#create_blueprint(params = {}) ⇒ Types::CreateBlueprintResponse
Creates an Amazon Bedrock Data Automation Blueprint.
-
#create_blueprint_version(params = {}) ⇒ Types::CreateBlueprintVersionResponse
Creates a new version of an existing Amazon Bedrock Data Automation Blueprint.
-
#create_data_automation_library(params = {}) ⇒ Types::CreateDataAutomationLibraryResponse
Creates an Amazon Bedrock Data Automation Library.
-
#create_data_automation_project(params = {}) ⇒ Types::CreateDataAutomationProjectResponse
Creates an Amazon Bedrock Data Automation Project.
-
#delete_blueprint(params = {}) ⇒ Struct
Deletes an existing Amazon Bedrock Data Automation Blueprint.
-
#delete_data_automation_library(params = {}) ⇒ Types::DeleteDataAutomationLibraryResponse
Deletes an existing Amazon Bedrock Data Automation Library.
-
#delete_data_automation_project(params = {}) ⇒ Types::DeleteDataAutomationProjectResponse
Deletes an existing Amazon Bedrock Data Automation Project.
-
#get_blueprint(params = {}) ⇒ Types::GetBlueprintResponse
Gets an existing Amazon Bedrock Data Automation Blueprint.
-
#get_blueprint_optimization_status(params = {}) ⇒ Types::GetBlueprintOptimizationStatusResponse
API used to get blueprint optimization status.
-
#get_data_automation_library(params = {}) ⇒ Types::GetDataAutomationLibraryResponse
Gets an existing Amazon Bedrock Data Automation Library.
-
#get_data_automation_library_entity(params = {}) ⇒ Types::GetDataAutomationLibraryEntityResponse
Gets an existing entity based on entity type from the library.
-
#get_data_automation_library_ingestion_job(params = {}) ⇒ Types::GetDataAutomationLibraryIngestionJobResponse
API used to get status of data automation library ingestion job.
-
#get_data_automation_project(params = {}) ⇒ Types::GetDataAutomationProjectResponse
Gets an existing Amazon Bedrock Data Automation Project.
-
#invoke_blueprint_optimization_async(params = {}) ⇒ Types::InvokeBlueprintOptimizationAsyncResponse
Invoke an async job to perform Blueprint Optimization.
-
#invoke_data_automation_library_ingestion_job(params = {}) ⇒ Types::InvokeDataAutomationLibraryIngestionJobResponse
Async API: Invoke data automation library ingestion job.
-
#list_blueprints(params = {}) ⇒ Types::ListBlueprintsResponse
Lists all existing Amazon Bedrock Data Automation Blueprints.
-
#list_data_automation_libraries(params = {}) ⇒ Types::ListDataAutomationLibrariesResponse
Lists all existing Amazon Bedrock Data Automation Libraries.
-
#list_data_automation_library_entities(params = {}) ⇒ Types::ListDataAutomationLibraryEntitiesResponse
Lists all stored entities in the library.
-
#list_data_automation_library_ingestion_jobs(params = {}) ⇒ Types::ListDataAutomationLibraryIngestionJobsResponse
Lists all data automation library ingestion jobs.
-
#list_data_automation_projects(params = {}) ⇒ Types::ListDataAutomationProjectsResponse
Lists all existing Amazon Bedrock Data Automation Projects.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource.
-
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource.
-
#update_blueprint(params = {}) ⇒ Types::UpdateBlueprintResponse
Updates an existing Amazon Bedrock Data Automation Blueprint.
-
#update_data_automation_library(params = {}) ⇒ Types::UpdateDataAutomationLibraryResponse
Updates an existing Amazon Bedrock Data Automation Library.
-
#update_data_automation_project(params = {}) ⇒ Types::UpdateDataAutomationProjectResponse
Updates an existing Amazon Bedrock Data Automation Project.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2242 2243 2244 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2242 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2245 2246 2247 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2245 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2215 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BedrockDataAutomation') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bedrockdataautomation' context[:gem_version] = '1.31.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_blueprint_stage(params = {}) ⇒ Struct
Copies a Blueprint from one stage to another
509 510 511 512 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 509 def copy_blueprint_stage(params = {}, = {}) req = build_request(:copy_blueprint_stage, params) req.send_request() end |
#create_blueprint(params = {}) ⇒ Types::CreateBlueprintResponse
Creates an Amazon Bedrock Data Automation Blueprint
590 591 592 593 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 590 def create_blueprint(params = {}, = {}) req = build_request(:create_blueprint, params) req.send_request() end |
#create_blueprint_version(params = {}) ⇒ Types::CreateBlueprintVersionResponse
Creates a new version of an existing Amazon Bedrock Data Automation Blueprint
642 643 644 645 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 642 def create_blueprint_version(params = {}, = {}) req = build_request(:create_blueprint_version, params) req.send_request() end |
#create_data_automation_library(params = {}) ⇒ Types::CreateDataAutomationLibraryResponse
Creates an Amazon Bedrock Data Automation Library
701 702 703 704 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 701 def create_data_automation_library(params = {}, = {}) req = build_request(:create_data_automation_library, params) req.send_request() end |
#create_data_automation_project(params = {}) ⇒ Types::CreateDataAutomationProjectResponse
Creates an Amazon Bedrock Data Automation Project
941 942 943 944 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 941 def create_data_automation_project(params = {}, = {}) req = build_request(:create_data_automation_project, params) req.send_request() end |
#delete_blueprint(params = {}) ⇒ Struct
Deletes an existing Amazon Bedrock Data Automation Blueprint
967 968 969 970 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 967 def delete_blueprint(params = {}, = {}) req = build_request(:delete_blueprint, params) req.send_request() end |
#delete_data_automation_library(params = {}) ⇒ Types::DeleteDataAutomationLibraryResponse
Deletes an existing Amazon Bedrock Data Automation Library
998 999 1000 1001 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 998 def delete_data_automation_library(params = {}, = {}) req = build_request(:delete_data_automation_library, params) req.send_request() end |
#delete_data_automation_project(params = {}) ⇒ Types::DeleteDataAutomationProjectResponse
Deletes an existing Amazon Bedrock Data Automation Project
1029 1030 1031 1032 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1029 def delete_data_automation_project(params = {}, = {}) req = build_request(:delete_data_automation_project, params) req.send_request() end |
#get_blueprint(params = {}) ⇒ Types::GetBlueprintResponse
Gets an existing Amazon Bedrock Data Automation Blueprint
1081 1082 1083 1084 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1081 def get_blueprint(params = {}, = {}) req = build_request(:get_blueprint, params) req.send_request() end |
#get_blueprint_optimization_status(params = {}) ⇒ Types::GetBlueprintOptimizationStatusResponse
API used to get blueprint optimization status.
1116 1117 1118 1119 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1116 def get_blueprint_optimization_status(params = {}, = {}) req = build_request(:get_blueprint_optimization_status, params) req.send_request() end |
#get_data_automation_library(params = {}) ⇒ Types::GetDataAutomationLibraryResponse
Gets an existing Amazon Bedrock Data Automation Library
1155 1156 1157 1158 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1155 def get_data_automation_library(params = {}, = {}) req = build_request(:get_data_automation_library, params) req.send_request() end |
#get_data_automation_library_entity(params = {}) ⇒ Types::GetDataAutomationLibraryEntityResponse
Gets an existing entity based on entity type from the library
1198 1199 1200 1201 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1198 def get_data_automation_library_entity(params = {}, = {}) req = build_request(:get_data_automation_library_entity, params) req.send_request() end |
#get_data_automation_library_ingestion_job(params = {}) ⇒ Types::GetDataAutomationLibraryIngestionJobResponse
API used to get status of data automation library ingestion job
1239 1240 1241 1242 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1239 def get_data_automation_library_ingestion_job(params = {}, = {}) req = build_request(:get_data_automation_library_ingestion_job, params) req.send_request() end |
#get_data_automation_project(params = {}) ⇒ Types::GetDataAutomationProjectResponse
Gets an existing Amazon Bedrock Data Automation Project
1354 1355 1356 1357 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1354 def get_data_automation_project(params = {}, = {}) req = build_request(:get_data_automation_project, params) req.send_request() end |
#invoke_blueprint_optimization_async(params = {}) ⇒ Types::InvokeBlueprintOptimizationAsyncResponse
Invoke an async job to perform Blueprint Optimization
1431 1432 1433 1434 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1431 def invoke_blueprint_optimization_async(params = {}, = {}) req = build_request(:invoke_blueprint_optimization_async, params) req.send_request() end |
#invoke_data_automation_library_ingestion_job(params = {}) ⇒ Types::InvokeDataAutomationLibraryIngestionJobResponse
Async API: Invoke data automation library ingestion job
1528 1529 1530 1531 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1528 def invoke_data_automation_library_ingestion_job(params = {}, = {}) req = build_request(:invoke_data_automation_library_ingestion_job, params) req.send_request() end |
#list_blueprints(params = {}) ⇒ Types::ListBlueprintsResponse
Lists all existing Amazon Bedrock Data Automation Blueprints
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1589 1590 1591 1592 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1589 def list_blueprints(params = {}, = {}) req = build_request(:list_blueprints, params) req.send_request() end |
#list_data_automation_libraries(params = {}) ⇒ Types::ListDataAutomationLibrariesResponse
Lists all existing Amazon Bedrock Data Automation Libraries
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1635 1636 1637 1638 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1635 def list_data_automation_libraries(params = {}, = {}) req = build_request(:list_data_automation_libraries, params) req.send_request() end |
#list_data_automation_library_entities(params = {}) ⇒ Types::ListDataAutomationLibraryEntitiesResponse
Lists all stored entities in the library
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1685 1686 1687 1688 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1685 def list_data_automation_library_entities(params = {}, = {}) req = build_request(:list_data_automation_library_entities, params) req.send_request() end |
#list_data_automation_library_ingestion_jobs(params = {}) ⇒ Types::ListDataAutomationLibraryIngestionJobsResponse
Lists all data automation library ingestion jobs
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1732 1733 1734 1735 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1732 def list_data_automation_library_ingestion_jobs(params = {}, = {}) req = build_request(:list_data_automation_library_ingestion_jobs, params) req.send_request() end |
#list_data_automation_projects(params = {}) ⇒ Types::ListDataAutomationProjectsResponse
Lists all existing Amazon Bedrock Data Automation Projects
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1795 1796 1797 1798 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1795 def list_data_automation_projects(params = {}, = {}) req = build_request(:list_data_automation_projects, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource
1825 1826 1827 1828 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1825 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource
1856 1857 1858 1859 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1856 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource
1882 1883 1884 1885 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1882 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_blueprint(params = {}) ⇒ Types::UpdateBlueprintResponse
Updates an existing Amazon Bedrock Data Automation Blueprint
1943 1944 1945 1946 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1943 def update_blueprint(params = {}, = {}) req = build_request(:update_blueprint, params) req.send_request() end |
#update_data_automation_library(params = {}) ⇒ Types::UpdateDataAutomationLibraryResponse
Updates an existing Amazon Bedrock Data Automation Library
1985 1986 1987 1988 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1985 def update_data_automation_library(params = {}, = {}) req = build_request(:update_data_automation_library, params) req.send_request() end |
#update_data_automation_project(params = {}) ⇒ Types::UpdateDataAutomationProjectResponse
Updates an existing Amazon Bedrock Data Automation Project
2206 2207 2208 2209 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2206 def update_data_automation_project(params = {}, = {}) req = build_request(:update_data_automation_project, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2235 2236 2237 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2235 def waiter_names [] end |