Class: Aws::BedrockDataAutomation::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BedrockDataAutomation::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bedrockdataautomation/client.rb
Overview
An API client for BedrockDataAutomation. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::BedrockDataAutomation::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#copy_blueprint_stage(params = {}) ⇒ Struct
Copies a Blueprint from one stage to another.
-
#create_blueprint(params = {}) ⇒ Types::CreateBlueprintResponse
Creates an Amazon Bedrock Data Automation Blueprint.
-
#create_blueprint_version(params = {}) ⇒ Types::CreateBlueprintVersionResponse
Creates a new version of an existing Amazon Bedrock Data Automation Blueprint.
-
#create_data_automation_library(params = {}) ⇒ Types::CreateDataAutomationLibraryResponse
Creates an Amazon Bedrock Data Automation Library.
-
#create_data_automation_project(params = {}) ⇒ Types::CreateDataAutomationProjectResponse
Creates an Amazon Bedrock Data Automation Project.
-
#delete_blueprint(params = {}) ⇒ Struct
Deletes an existing Amazon Bedrock Data Automation Blueprint.
-
#delete_data_automation_library(params = {}) ⇒ Types::DeleteDataAutomationLibraryResponse
Deletes an existing Amazon Bedrock Data Automation Library.
-
#delete_data_automation_project(params = {}) ⇒ Types::DeleteDataAutomationProjectResponse
Deletes an existing Amazon Bedrock Data Automation Project.
-
#get_blueprint(params = {}) ⇒ Types::GetBlueprintResponse
Gets an existing Amazon Bedrock Data Automation Blueprint.
-
#get_blueprint_optimization_status(params = {}) ⇒ Types::GetBlueprintOptimizationStatusResponse
API used to get blueprint optimization status.
-
#get_data_automation_library(params = {}) ⇒ Types::GetDataAutomationLibraryResponse
Gets an existing Amazon Bedrock Data Automation Library.
-
#get_data_automation_library_entity(params = {}) ⇒ Types::GetDataAutomationLibraryEntityResponse
Gets an existing entity based on entity type from the library.
-
#get_data_automation_library_ingestion_job(params = {}) ⇒ Types::GetDataAutomationLibraryIngestionJobResponse
API used to get status of data automation library ingestion job.
-
#get_data_automation_project(params = {}) ⇒ Types::GetDataAutomationProjectResponse
Gets an existing Amazon Bedrock Data Automation Project.
-
#invoke_blueprint_optimization_async(params = {}) ⇒ Types::InvokeBlueprintOptimizationAsyncResponse
Invoke an async job to perform Blueprint Optimization.
-
#invoke_data_automation_library_ingestion_job(params = {}) ⇒ Types::InvokeDataAutomationLibraryIngestionJobResponse
Async API: Invoke data automation library ingestion job.
-
#list_blueprints(params = {}) ⇒ Types::ListBlueprintsResponse
Lists all existing Amazon Bedrock Data Automation Blueprints.
-
#list_data_automation_libraries(params = {}) ⇒ Types::ListDataAutomationLibrariesResponse
Lists all existing Amazon Bedrock Data Automation Libraries.
-
#list_data_automation_library_entities(params = {}) ⇒ Types::ListDataAutomationLibraryEntitiesResponse
Lists all stored entities in the library.
-
#list_data_automation_library_ingestion_jobs(params = {}) ⇒ Types::ListDataAutomationLibraryIngestionJobsResponse
Lists all data automation library ingestion jobs.
-
#list_data_automation_projects(params = {}) ⇒ Types::ListDataAutomationProjectsResponse
Lists all existing Amazon Bedrock Data Automation Projects.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource.
-
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource.
-
#update_blueprint(params = {}) ⇒ Types::UpdateBlueprintResponse
Updates an existing Amazon Bedrock Data Automation Blueprint.
-
#update_data_automation_library(params = {}) ⇒ Types::UpdateDataAutomationLibraryResponse
Updates an existing Amazon Bedrock Data Automation Library.
-
#update_data_automation_project(params = {}) ⇒ Types::UpdateDataAutomationProjectResponse
Updates an existing Amazon Bedrock Data Automation Project.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2244 2245 2246 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2244 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2247 2248 2249 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2247 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2217 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BedrockDataAutomation') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bedrockdataautomation' context[:gem_version] = '1.30.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_blueprint_stage(params = {}) ⇒ Struct
Copies a Blueprint from one stage to another
511 512 513 514 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 511 def copy_blueprint_stage(params = {}, = {}) req = build_request(:copy_blueprint_stage, params) req.send_request() end |
#create_blueprint(params = {}) ⇒ Types::CreateBlueprintResponse
Creates an Amazon Bedrock Data Automation Blueprint
592 593 594 595 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 592 def create_blueprint(params = {}, = {}) req = build_request(:create_blueprint, params) req.send_request() end |
#create_blueprint_version(params = {}) ⇒ Types::CreateBlueprintVersionResponse
Creates a new version of an existing Amazon Bedrock Data Automation Blueprint
644 645 646 647 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 644 def create_blueprint_version(params = {}, = {}) req = build_request(:create_blueprint_version, params) req.send_request() end |
#create_data_automation_library(params = {}) ⇒ Types::CreateDataAutomationLibraryResponse
Creates an Amazon Bedrock Data Automation Library
703 704 705 706 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 703 def create_data_automation_library(params = {}, = {}) req = build_request(:create_data_automation_library, params) req.send_request() end |
#create_data_automation_project(params = {}) ⇒ Types::CreateDataAutomationProjectResponse
Creates an Amazon Bedrock Data Automation Project
943 944 945 946 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 943 def create_data_automation_project(params = {}, = {}) req = build_request(:create_data_automation_project, params) req.send_request() end |
#delete_blueprint(params = {}) ⇒ Struct
Deletes an existing Amazon Bedrock Data Automation Blueprint
969 970 971 972 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 969 def delete_blueprint(params = {}, = {}) req = build_request(:delete_blueprint, params) req.send_request() end |
#delete_data_automation_library(params = {}) ⇒ Types::DeleteDataAutomationLibraryResponse
Deletes an existing Amazon Bedrock Data Automation Library
1000 1001 1002 1003 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1000 def delete_data_automation_library(params = {}, = {}) req = build_request(:delete_data_automation_library, params) req.send_request() end |
#delete_data_automation_project(params = {}) ⇒ Types::DeleteDataAutomationProjectResponse
Deletes an existing Amazon Bedrock Data Automation Project
1031 1032 1033 1034 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1031 def delete_data_automation_project(params = {}, = {}) req = build_request(:delete_data_automation_project, params) req.send_request() end |
#get_blueprint(params = {}) ⇒ Types::GetBlueprintResponse
Gets an existing Amazon Bedrock Data Automation Blueprint
1083 1084 1085 1086 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1083 def get_blueprint(params = {}, = {}) req = build_request(:get_blueprint, params) req.send_request() end |
#get_blueprint_optimization_status(params = {}) ⇒ Types::GetBlueprintOptimizationStatusResponse
API used to get blueprint optimization status.
1118 1119 1120 1121 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1118 def get_blueprint_optimization_status(params = {}, = {}) req = build_request(:get_blueprint_optimization_status, params) req.send_request() end |
#get_data_automation_library(params = {}) ⇒ Types::GetDataAutomationLibraryResponse
Gets an existing Amazon Bedrock Data Automation Library
1157 1158 1159 1160 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1157 def get_data_automation_library(params = {}, = {}) req = build_request(:get_data_automation_library, params) req.send_request() end |
#get_data_automation_library_entity(params = {}) ⇒ Types::GetDataAutomationLibraryEntityResponse
Gets an existing entity based on entity type from the library
1200 1201 1202 1203 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1200 def get_data_automation_library_entity(params = {}, = {}) req = build_request(:get_data_automation_library_entity, params) req.send_request() end |
#get_data_automation_library_ingestion_job(params = {}) ⇒ Types::GetDataAutomationLibraryIngestionJobResponse
API used to get status of data automation library ingestion job
1241 1242 1243 1244 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1241 def get_data_automation_library_ingestion_job(params = {}, = {}) req = build_request(:get_data_automation_library_ingestion_job, params) req.send_request() end |
#get_data_automation_project(params = {}) ⇒ Types::GetDataAutomationProjectResponse
Gets an existing Amazon Bedrock Data Automation Project
1356 1357 1358 1359 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1356 def get_data_automation_project(params = {}, = {}) req = build_request(:get_data_automation_project, params) req.send_request() end |
#invoke_blueprint_optimization_async(params = {}) ⇒ Types::InvokeBlueprintOptimizationAsyncResponse
Invoke an async job to perform Blueprint Optimization
1433 1434 1435 1436 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1433 def invoke_blueprint_optimization_async(params = {}, = {}) req = build_request(:invoke_blueprint_optimization_async, params) req.send_request() end |
#invoke_data_automation_library_ingestion_job(params = {}) ⇒ Types::InvokeDataAutomationLibraryIngestionJobResponse
Async API: Invoke data automation library ingestion job
1530 1531 1532 1533 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1530 def invoke_data_automation_library_ingestion_job(params = {}, = {}) req = build_request(:invoke_data_automation_library_ingestion_job, params) req.send_request() end |
#list_blueprints(params = {}) ⇒ Types::ListBlueprintsResponse
Lists all existing Amazon Bedrock Data Automation Blueprints
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1591 1592 1593 1594 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1591 def list_blueprints(params = {}, = {}) req = build_request(:list_blueprints, params) req.send_request() end |
#list_data_automation_libraries(params = {}) ⇒ Types::ListDataAutomationLibrariesResponse
Lists all existing Amazon Bedrock Data Automation Libraries
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1637 1638 1639 1640 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1637 def list_data_automation_libraries(params = {}, = {}) req = build_request(:list_data_automation_libraries, params) req.send_request() end |
#list_data_automation_library_entities(params = {}) ⇒ Types::ListDataAutomationLibraryEntitiesResponse
Lists all stored entities in the library
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1687 1688 1689 1690 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1687 def list_data_automation_library_entities(params = {}, = {}) req = build_request(:list_data_automation_library_entities, params) req.send_request() end |
#list_data_automation_library_ingestion_jobs(params = {}) ⇒ Types::ListDataAutomationLibraryIngestionJobsResponse
Lists all data automation library ingestion jobs
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1734 1735 1736 1737 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1734 def list_data_automation_library_ingestion_jobs(params = {}, = {}) req = build_request(:list_data_automation_library_ingestion_jobs, params) req.send_request() end |
#list_data_automation_projects(params = {}) ⇒ Types::ListDataAutomationProjectsResponse
Lists all existing Amazon Bedrock Data Automation Projects
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1797 1798 1799 1800 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1797 def list_data_automation_projects(params = {}, = {}) req = build_request(:list_data_automation_projects, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource
1827 1828 1829 1830 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1827 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource
1858 1859 1860 1861 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1858 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource
1884 1885 1886 1887 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1884 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_blueprint(params = {}) ⇒ Types::UpdateBlueprintResponse
Updates an existing Amazon Bedrock Data Automation Blueprint
1945 1946 1947 1948 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1945 def update_blueprint(params = {}, = {}) req = build_request(:update_blueprint, params) req.send_request() end |
#update_data_automation_library(params = {}) ⇒ Types::UpdateDataAutomationLibraryResponse
Updates an existing Amazon Bedrock Data Automation Library
1987 1988 1989 1990 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 1987 def update_data_automation_library(params = {}, = {}) req = build_request(:update_data_automation_library, params) req.send_request() end |
#update_data_automation_project(params = {}) ⇒ Types::UpdateDataAutomationProjectResponse
Updates an existing Amazon Bedrock Data Automation Project
2208 2209 2210 2211 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2208 def update_data_automation_project(params = {}, = {}) req = build_request(:update_data_automation_project, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2237 2238 2239 |
# File 'lib/aws-sdk-bedrockdataautomation/client.rb', line 2237 def waiter_names [] end |